%global pypi_name scitokens-credmon

Name:           %{pypi_name}
Version:        0.8.1
Release:        1.3%{?dist}
Summary:        SciTokens credential monitor for use with HTCondor

License:        MIT
URL:            https://github.com/htcondor/scitokens-credmon
Source0:        %{pypi_name}-%{version}.tar.gz
Patch0:         Open-temp-file-as-bytes-for-atomic_output-to-fix-str.patch
BuildArch:      noarch

%if 0%{?rhel} < 8 && 0%{?fedora} < 31
%define python python2
%define __python %{__python2}
%define python_min_version 2.7
%else
%define python python3
%define __python %{__python3}
%define python_min_version 3.6
%endif

BuildRequires:  %{python}-devel >= %{python_min_version}
BuildRequires:  %{python}-setuptools

%description
A HTCondor credentials monitor specific for OAuth2 and SciTokens workflows.

%package -n     %{python}-%{pypi_name}
Summary:        SciTokens credential monitor for use with HTCondor

# old version of %%python_provide doesn't handle python3 correctly; do what it does by hand
Provides:       python-%{pypi_name} = %{version}-%{release}
Obsoletes:      python-%{pypi_name} < %{version}-%{release}
 
Requires:       %{python}-condor
Requires:       %{python}-requests-oauthlib
Requires:       %{python}-cryptography
Requires:       %{python}-scitokens
%if 0%{?rhel} < 8 && 0%{?fedora} < 31
Requires:       python-six
Requires:       python-flask
Requires:       mod_wsgi
%else
Requires:       %{python}-six
Requires:       %{python}-flask
Requires:       %{python}-mod_wsgi
%global __requires_exclude ^python.*\\(htcondor\\)
# ^^ avoids autogenerated dependencies like `python3.6dist(htcondor)`; we require the condor python bindings explicitly
%endif
Requires:       condor >= 8.8.2
Requires:       httpd

%description -n %{python}-%{pypi_name}


%prep
%autosetup -n %{pypi_name}-%{version} -p 1
# Remove pre-built egg-info
rm -rf %{pypi_name}.egg-info

%build
%py_build

%install
%py_install
ln -s %{_bindir}/condor_credmon_oauth %{buildroot}/%{_bindir}/scitokens_credmon
mkdir -p %{buildroot}/%{_var}/lib/condor/oauth_credentials
mv examples/config/README.credentials %{buildroot}/%{_var}/lib/condor/oauth_credentials
mkdir -p %{buildroot}/%{_var}/www/wsgi-scripts/scitokens-credmon
mv examples/wsgi/scitokens-credmon.wsgi %{buildroot}/%{_var}/www/wsgi-scripts/scitokens-credmon/scitokens-credmon.wsgi
rmdir examples/wsgi

%files -n %{python}-%{pypi_name}
%doc LICENSE README.md examples
%{_bindir}/condor_credmon_oauth
%{_bindir}/scitokens_credmon
%{_bindir}/scitokens_credential_producer
%{python_sitelib}/credmon
%{python_sitelib}/scitokens_credmon-*.egg-info
%{_var}/lib/condor/oauth_credentials/README.credentials
%ghost %{_var}/lib/condor/oauth_credentials/wsgi_session_key
%ghost %{_var}/lib/condor/oauth_credentials/CREDMON_COMPLETE
%ghost %{_var}/lib/condor/oauth_credentials/pid
%{_var}/www/wsgi-scripts/scitokens-credmon

%changelog
* Mon Dec 12 2022 Carl Edquist <edquist@cs.wisc.edu> - 0.8.1-1.3
- Bump to release (SOFTWARE-5384)

* Thu Oct 01 2020 Mátyás Selmeci <matyas@cs.wisc.edu> - 0.8.1-1.2
- Fix Python 3 bytes/str issue
  Added patch Open-temp-file-as-bytes-for-atomic_output-to-fix-str.patch

* Wed Sep 30 2020 Mátyás Selmeci <matyas@cs.wisc.edu> - 0.8.1-1.1
- Build for OSG; change version to match Git tag (SOFTWARE-4274)
- Use Python 3 for RHEL 8

* Thu Sep 24 2020 Jason Patton <jpatton@cs.wisc.edu> - 0.8-2
- Hacks for getting local issuer working with old krb behavior.

* Thu Sep 24 2020 Jason Patton <jpatton@cs.wisc.edu> - 0.8-1
- Python 3 compatibility
- Credmon subprocess returns on parent exit
- condor_who now reports credmon as Ready
- Local issuer no longer refreshes tokens every loop

* Mon Jun 01 2020 Jason Patton <jpatton@cs.wisc.edu> - 0.7-1
- Use dweitzel\'s subprocess queuing

* Tue Mar 31 2020 Jason Patton <jpatton@cs.wisc.edu> - 0.6-1
- Conform to new HTCondor OAuth config behavior

* Thu Mar 05 2020 Jason Patton <jpatton@cs.wisc.edu> - 0.5-1
- Change token deletion behavior.

* Tue Oct 08 2019 Jason Patton <jpatton@cs.wisc.edu> - 0.4-1
- Move configuration into examples directory.

* Thu May 02 2019 Jason Patton <jpatton@cs.wisc.edu> - 0.3-1
- Remove automatic install of config files. Put README in creddir.

* Fri Feb 08 2019 Brian Bockelman <brian.bockelman@cern.ch> - 0.2-1
- Include proper packaging and WSGI scripts for credmon.

* Fri Feb 08 2019 Brian Bockelman <brian.bockelman@cern.ch> - 0.1-1
- Initial package version as uploaded to the Test PyPI instance.
